'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var reactBootstrap = require('react-bootstrap');
var Control = _interopDefault(require('react-bootstrap/FormControl'));
var formik = require('formik');

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var getFieldErrorProps = function getFieldErrorProps(_ref) {
  var field = _ref.field,
      form = _ref.form,
      isTouchRequired = _ref.isTouchRequired;
  var fieldError = field.name ? formik.getIn(form.errors, field.name) : '';
  var showError = isTouchRequired && formik.getIn(form.touched, field.name) && !!fieldError || !isTouchRequired && !!fieldError;
  return {
    fieldError: fieldError,
    showError: showError
  };
};
var getFieldFormControlProps = function getFieldFormControlProps(_ref2) {
  var disabled = _ref2.disabled,
      field = _ref2.field,
      tag = _ref2.tag,
      isInvalid = _ref2.isInvalid,
      _ref2$isTouchRequired = _ref2.isTouchRequired,
      isTouchRequired = _ref2$isTouchRequired === void 0 ? true : _ref2$isTouchRequired,
      form = _ref2.form,
      props = _objectWithoutPropertiesLoose(_ref2, ["disabled", "field", "tag", "isInvalid", "isTouchRequired", "form"]);

  var _getFieldErrorProps = getFieldErrorProps({
    field: field,
    form: form,
    isTouchRequired: isTouchRequired
  }),
      showError = _getFieldErrorProps.showError;

  return _extends({}, field, {}, props, {
    isInvalid: isInvalid !== null && isInvalid !== void 0 ? isInvalid : showError,
    disabled: disabled || form.isSubmitting,
    as: tag
  });
};
var getFieldFormCheckProps = function getFieldFormCheckProps(_ref3) {
  var disabled = _ref3.disabled,
      field = _ref3.field,
      isInvalid = _ref3.isInvalid,
      _ref3$isTouchRequired = _ref3.isTouchRequired,
      isTouchRequired = _ref3$isTouchRequired === void 0 ? true : _ref3$isTouchRequired,
      form = _ref3.form,
      props = _objectWithoutPropertiesLoose(_ref3, ["disabled", "field", "isInvalid", "isTouchRequired", "form"]);

  var _getFieldErrorProps2 = getFieldErrorProps({
    field: field,
    form: form,
    isTouchRequired: isTouchRequired
  }),
      showError = _getFieldErrorProps2.showError,
      fieldError = _getFieldErrorProps2.fieldError;

  return _extends({}, field, {}, props, {
    isInvalid: isInvalid !== null && isInvalid !== void 0 ? isInvalid : showError,
    feedback: fieldError,
    disabled: disabled || form.isSubmitting
  });
};
var getFieldFormFeedbackType = function getFieldFormFeedbackType(_ref4) {
  var field = _ref4.field,
      isInvalid = _ref4.isInvalid,
      _ref4$isTouchRequired = _ref4.isTouchRequired,
      isTouchRequired = _ref4$isTouchRequired === void 0 ? true : _ref4$isTouchRequired,
      form = _ref4.form;

  var _getFieldErrorProps3 = getFieldErrorProps({
    field: field,
    form: form,
    isTouchRequired: isTouchRequired
  }),
      showError = _getFieldErrorProps3.showError;

  return (isInvalid !== null && isInvalid !== void 0 ? isInvalid : showError) ? 'invalid' : 'valid';
};

var FORM_CHECK_TEST_ID = 'form-check';
var FORM_CONTROL_TEST_ID = 'form-control';
var FORM_FEEDBACK_TEST_ID = 'form-control-feedback';
var FORM_GROUP_TEST_ID = 'form-group';
var FORM_LABEL_TEST_ID = 'form-label';
var FORM_GROUP_FEEDBACK_TEST_ID = 'form-feedback';

var FormControlFeedback = function FormControlFeedback(props) {
  var children = props.children,
      className = props.className;
  if (!children) return null;
  return React.createElement(reactBootstrap.FormControl.Feedback, {
    type: "invalid",
    className: className,
    "data-testid": FORM_FEEDBACK_TEST_ID
  }, children);
};

var FormControl = function FormControl(_ref) {
  var children = _ref.children,
      props = _objectWithoutPropertiesLoose(_ref, ["children"]);

  return React.createElement(Control, Object.assign({}, getFieldFormControlProps(props), {
    "data-testid": FORM_CONTROL_TEST_ID
  }), children);
};

FormControl.displayName = 'FormControl';
FormControl.Feedback = FormControlFeedback;

var FormGroup = function FormGroup(_ref) {
  var label = _ref.label,
      tag = _ref.tag,
      controlTag = _ref.controlTag,
      props = _objectWithoutPropertiesLoose(_ref, ["label", "tag", "controlTag"]);

  var _getFieldErrorProps = getFieldErrorProps(props),
      showError = _getFieldErrorProps.showError,
      fieldError = _getFieldErrorProps.fieldError;

  return React.createElement(reactBootstrap.Form.Group, {
    "data-testid": FORM_GROUP_TEST_ID,
    as: tag
  }, label && React.createElement(reactBootstrap.Form.Label, {
    "data-testid": FORM_LABEL_TEST_ID
  }, label), React.createElement(FormControl, Object.assign({}, props, {
    tag: controlTag
  })), showError && fieldError && React.createElement(reactBootstrap.Form.Control.Feedback, {
    type: getFieldFormFeedbackType(props),
    "data-testid": FORM_GROUP_FEEDBACK_TEST_ID
  }, fieldError));
};

FormGroup.displayName = 'FormGroup';

var FormCheck = function FormCheck(props) {
  return React.createElement(reactBootstrap.Form.Check, Object.assign({}, getFieldFormCheckProps(props), {
    "data-testid": FORM_CHECK_TEST_ID
  }));
};

exports.FormCheck = FormCheck;
exports.FormControl = FormControl;
exports.FormControlFeedback = FormControlFeedback;
exports.FormGroup = FormGroup;
//# sourceMappingURL=formik-ui-bootstrap.cjs.development.js.map
